;-----------------------------------------------------------------------------
;                                12F683            								    *								*
;                             -----uu-----                       
;                   +5 V ----| vdd    vss |---- Gnd
;                            | gp5    gp0 | 
;                            | gp4    gp1 | 
;                            | gp3    gp2 |---> LED 
;                             ------------ 
;
;-----------------------------------------------------------------------------


	list P=12F683, ST=OFF           ; Turnoff Symbol Table in List file.
        errorlevel  -302                ; Ignore error message when storing to Bank 1.

	#include "p12f683.inc"          ; processor specific variable definitions

;-----------------------------------------------------------------------------
;  Configuration bits
;-----------------------------------------------------------------------------
   __config _INTOSCIO & _WDT_OFF & _PWRTE_ON & _MCLRE_OFF & _CP_OFF & _CPD_OFF & _BOD_NSLEEP & _IESO_OFF & _FCMEN_OFF

;-----------------------------------------------------------------------------
;  VARIABLE DEFINITIONS
;-----------------------------------------------------------------------------
        CBLOCK 0x20
	d1
	d2
	d3
        ENDC 


;-----------------------------------------------------------------------------
;  PROGRAM CODE
;-----------------------------------------------------------------------------
	ORG     0x000           	; processor reset vector
	goto    MAIN            	; go to beginning of program

;-----------------------------------------------------------------------------
;  MAIN ROUTINE START HERE
;-----------------------------------------------------------------------------
MAIN:
        BANKSEL CMCON0                  ; Switch to Bank 0.
        MOVLW   b'00000111'             ; Turn off Analog Comparator.
        MOVWF   CMCON0 
        CLRF    GPIO
        BANKSEL TRISIO                  ; Switch to Bank 1.
        MOVLW   ~(1<<GP2)               ; configure GP2 (only) as an output
        MOVWF   TRISIO
        CLRF ANSEL                      ; Enable digital I/O function 
        MOVLW   b'01110001'             ; 8MHz Clk, IntOsc, SysClk via IntOsc
        MOVWF   OSCCON
        banksel GPIO                    ; Switch to Bank 0.

;-----------------------------------------------------------------------------
;  ENDLESS LOOP START HERE
;-----------------------------------------------------------------------------
LOOP:   
        MOVLW   1<<GP2
        XORWF   GPIO,F                  ; toggle LED
        CALL    Delay
        goto    LOOP    

;-----------------------------------------------------------------------------
;  Delay = 0.25 seconds
;  Clock frequency = 8 MHz
;-----------------------------------------------------------------------------
Delay
	
	movlw	0x03
	movwf	d1
	movlw	0x18
	movwf	d2
	movlw	0x02
	movwf	d3
Delay_0
	decfsz	d1, f
	goto	$+2
	decfsz	d2, f
	goto	$+2
	decfsz	d3, f
	goto	Delay_0
	goto	$+1
	return

;-----------------------------------------------------------------------------
	END                             ; directive 'end of program'
;-----------------------------------------------------------------------------
